import pytest

from program.tests.factories import TypeFactory

pytestmark = pytest.mark.django_db


def url(type=None):
    return f"/api/v1/types/{type.id}/" if type else "/api/v1/types/"


def test_create(admin_api_client):
    data = {
        "name": "NAME",
        "slug": "type",
    }

    response = admin_api_client.post(url(), data)

    assert response.status_code == 201

    assert response.data["name"] == data["name"]
    assert response.data["slug"] == data["slug"]


def test_retrieve(common_api_client1, type_):
    response = common_api_client1.get(url(type_))

    assert response.status_code == 200

    assert response.data["name"] == type_.name
    assert response.data["slug"] == type_.slug


def test_delete(admin_api_client, type_):
    response = admin_api_client.delete(url(type=type_))

    assert response.status_code == 204


def test_list(common_api_client1):
    TYPES = 3
    TypeFactory.create_batch(size=TYPES)

    response = common_api_client1.get(url())

    assert response.status_code == 200
    assert len(response.data) == TYPES


def test_update_is_active(admin_api_client, type_):
    update = {"is_active": False}

    response = admin_api_client.patch(url(type=type_), update)

    assert response.status_code == 200
    assert response.data["is_active"] is update["is_active"]


def test_update_name(admin_api_client, type_):
    update = {"name": "NAME"}

    response = admin_api_client.patch(url(type=type_), update)

    assert response.status_code == 200
    assert response.data["name"] == update["name"]


def test_update_slug(admin_api_client, type_):
    update = {"slug": "topic"}

    response = admin_api_client.patch(url(type=type_), update)

    assert response.status_code == 200
    assert response.data["slug"] == update["slug"]
